@@ -24,8 +24,7 @@ from troposphere import Ref
 from troposphere.ecs import HealthCheck
 from troposphere.iam import Policy
 
-from ecs_composex.common import NONALPHANUM
-from ecs_composex.common import keyisset, LOG
+from ecs_composex.common import keyisset, keypresent, LOG
 from ecs_composex.ecs import ecs_params
 from ecs_composex.ecs.docker_tools import set_memory_to_mb
 from ecs_composex.iam import define_iam_policy
@@ -136,7 +135,7 @@ def set_service_ports(ports):
             )
         elif isinstance(port, dict):
             if not set(port).issubset(valid_keys):
-                raise KeyError(f"Valid keys are", valid_keys, "got", port.keys())
+                raise KeyError("Valid keys are", valid_keys, "got", port.keys())
             port["mode"] = "awsvpc"
             service_ports.append(port)
         elif isinstance(port, int):
@@ -205,11 +204,12 @@ class ServiceConfig(object):
         "deploy",
         "external_links",
     ]
+    scaling_key = "scaling"
     required_keys = ["image"]
 
     master_key = "x-configs"
     composex_key = "composex"
-    valid_config_keys = ["network", "iam", "x-ray", "logging"]
+    valid_config_keys = ["network", "iam", "x-ray", "logging", scaling_key]
 
     network_defaults = {
         "use_cloudmap": True,
@@ -218,17 +218,18 @@ class ServiceConfig(object):
         "ingress": None,
     }
 
-    def __init__(self, content, service_name, definition, family_name=None):
+    def __init__(self, service, content, family_name=None):
         """
         Function to initialize the ecs_service configuration
         :param content:
+        :param ecs_composex.common.compose_resources.XResource service:
         """
+        self.resource = service
         service_configs = keyset_else_novalue(
-            self.master_key, definition, else_value={}
+            self.master_key, self.resource.definition, else_value={}
         )
         self.network = None
         self.iam = None
-
         self.lb_type = None
         self.healthcheck = None
         self.ext_sources = None
@@ -238,54 +239,68 @@ class ServiceConfig(object):
         self.use_cloudmap = True
         self.use_appmesh = False
         self.boundary = None
+        self.target_scaling_config = None
+        self.scaling_range = None
         self.policies = []
         self.managed_policies = []
         self.container_start_condition = "START"
-        self.service_name = service_name if service_name else "global"
+        self.replicas = int(ecs_params.SERVICE_COUNT.Default)
+        self.family_dependents = []
+        self.essential = False
+        self.volumes = []
+        self.cpu_alloc = Ref(AWS_NO_VALUE)
+        self.cpu_resa = Ref(AWS_NO_VALUE)
+        self.mem_alloc = Ref(AWS_NO_VALUE)
+        self.mem_resa = Ref(AWS_NO_VALUE)
+        self.service = None
+        self.use_xray = False
         self.logs_retention_period = ecs_params.LOG_GROUP_RETENTION.Default
         if keyisset("x-appmesh", content):
             self.use_appmesh = True
 
         if keyisset(self.master_key, content):
             self.set_from_top_configs(content)
-        if service_name and isinstance(service_configs, dict):
-            self.define_service_config(content, service_name, service_configs)
+        if self.resource.name and isinstance(service_configs, dict):
+            self.define_service_config(content, self.resource.name, service_configs)
 
-        if not set(self.required_keys).issubset(set(definition)):
+        if not set(self.required_keys).issubset(set(self.resource.definition)):
             raise AttributeError(
-                "Required attributes for a ecs_service are", self.required_keys
+                f"Service {self.resource.name} is missing required attributes."
+                "Required attributes for a ecs_service are",
+                self.required_keys,
             )
-        self.family_dependents = []
-        self.essential = False
-        self.volumes = []
-        self.links = (keyset_else_novalue("external_links", definition, else_value=[]),)
-        self.service = None
-        self.use_xray = False
-        self.replicas = int(ecs_params.SERVICE_COUNT.Default)
-        self.cpu_alloc = Ref(AWS_NO_VALUE)
-        self.cpu_resa = Ref(AWS_NO_VALUE)
-        self.mem_alloc = Ref(AWS_NO_VALUE)
-        self.mem_resa = Ref(AWS_NO_VALUE)
-        self.service_name = service_name
-        self.resource_name = NONALPHANUM.sub("", service_name)
+
+        self.links = keyset_else_novalue(
+            "external_links", self.resource.definition, else_value=[]
+        )
         self.command = (
-            definition["command"].strip() if keyisset("command", definition) else None
+            self.resource.definition["command"].strip()
+            if keyisset("command", self.resource.definition)
+            else None
+        )
+        self.entrypoint = keyset_else_novalue(
+            "entrypoint", self.resource.definition, else_value=None
         )
-        self.entrypoint = keyset_else_novalue("entrypoint", definition, else_value=None)
         self.ports = (
-            set_service_ports(definition["ports"])
-            if keyisset("ports", definition)
+            set_service_ports(self.resource.definition["ports"])
+            if keyisset("ports", self.resource.definition)
             else []
         )
         self.ingress_mappings = define_ingress_mappings(self.ports)
-        self.environment = keyset_else_novalue("environment", definition, else_value=[])
-        self.hostname = keyset_else_novalue("hostname", definition, else_value=None)
+        self.environment = keyset_else_novalue(
+            "environment", self.resource.definition, else_value=[]
+        )
+        self.hostname = keyset_else_novalue(
+            "hostname", self.resource.definition, else_value=None
+        )
         self.family_name = family_name
-        self.set_service_deploy(definition)
-        self.lb_service_name = service_name
-        self.set_xray(definition)
-        self.healthcheck = set_healthcheck(definition)
-        self.depends_on = keyset_else_novalue("depends_on", definition, else_value=[])
+        self.set_service_deploy(self.resource.definition)
+        self.lb_service_name = self.family_name
+        self.set_xray(self.resource.definition)
+        self.healthcheck = set_healthcheck(self.resource.definition)
+        self.depends_on = keyset_else_novalue(
+            "depends_on", self.resource.definition, else_value=[]
+        )
 
     def __add__(self, other):
         """
@@ -297,7 +312,6 @@ class ServiceConfig(object):
                 self.ports = other.ports
                 self.lb_type = other.lb_type
                 self.is_public = other.is_public
-
         elif self.lb_type is not None and other.lb_type is not None:
             if self.is_public:
                 pass
@@ -311,6 +325,8 @@ class ServiceConfig(object):
             self.use_xray = True
         if self.links or other.links:
             self.links += other.links
+        if not self.target_scaling_config and other.target_scaling_config:
+            self.target_scaling_config = other.target_scaling_config
         return self
 
     def add_managed_policies(self, policies):
@@ -318,6 +334,71 @@ class ServiceConfig(object):
             policy_def = define_iam_policy(policy)
             self.managed_policies.append(policy_def)
 
+    def set_target_scaling(self, config):
+        """
+        Method to define target_scaling
+
+        :param dict config:
+        :return:
+        """
+        allowed_keys = {
+            "cpu_target": int,
+            "memory_target": int,
+            "lb_targets": int,
+            "scale_in_cooldown": int,
+            "scale_out_cooldown": int,
+            "disable_scale_in": bool,
+        }
+        default_values = {
+            "scale_out_cooldown": 300,
+            "scale_in_cooldown": 300,
+            "disable_scale_in": False,
+        }
+        scaling_configuration = {}
+        for key in allowed_keys.keys():
+            if not keyisset(key, config) and keypresent(key, default_values):
+                scaling_configuration[key] = default_values[key]
+            elif keypresent(key, config) and isinstance(config[key], allowed_keys[key]):
+                scaling_configuration[key] = config[key]
+            elif keyisset(key, config) and not isinstance(
+                config[key], allowed_keys[key]
+            ):
+                raise TypeError(
+                    f"Scaling configuration {key} is of type",
+                    type(config[key]),
+                    "Expected",
+                    allowed_keys[key],
+                )
+        LOG.debug(scaling_configuration)
+        self.target_scaling_config = scaling_configuration
+
+    def init_scaling(self, config):
+        """
+        Method to setup target scaling for the service.
+        :return:
+        """
+        LOG.debug("Setting target scaling")
+        allowed_keys = {"range": str, "target_scaling": dict, "allow_zero": bool}
+        if not all(key in list(allowed_keys.keys()) for key in config.keys()):
+            raise KeyError(
+                "Found invalid key. Got",
+                config,
+                "Allowed",
+                allowed_keys,
+            )
+        if not keyisset("range", config):
+            raise KeyError(
+                "Missing range property. Range should written as follows: {min}-{max}"
+            )
+        self.scaling_range = {
+            "max": int(config["range"].split("-")[-1]),
+            "min": int(config["range"].split("-")[0]),
+        }
+        if keyisset("allow_zero", config) and not self.scaling_range["min"] == 0:
+            self.scaling_range["min"] = 0
+        if keyisset("target_scaling", config):
+            self.set_target_scaling(config["target_scaling"])
+
     def add_policies(self, policies):
 
         for count, policy in enumerate(policies):
@@ -410,7 +491,7 @@ class ServiceConfig(object):
         for key_name in self.network_defaults:
             if key_name not in config.keys() and not hasattr(self, key_name):
                 LOG.info(
-                    f"Missing {key_name}. Setting to default - {self.service_name}"
+                    f"Missing {key_name}. Setting to default - {self.resource.name}"
                 )
                 setattr(self, key_name, self.network_defaults[key_name])
             elif key_name in config.keys():
@@ -462,7 +543,7 @@ class ServiceConfig(object):
         self.set_service_config(config_definition)
         if self.use_appmesh and not self.use_cloudmap:
             LOG.warning(
-                f"You turned CloudMap off, however aim to use AppMesh. So we are enabling ClouMap for the services"
+                "You turned CloudMap off, however aim to use AppMesh. So we are enabling ClouMap for the services"
             )
             self.use_cloudmap = True
 
