@@ -26,13 +26,17 @@ from ecs_composex.kms.kms_params import KMS_KEY_ARN_T
 from ecs_composex.kms.kms_perms import ACCESS_TYPES
 from ecs_composex.resource_permissions import apply_iam_based_resources
 from ecs_composex.resource_settings import (
-    generate_resource_envvars,
     generate_resource_permissions,
 )
 
 
 def handle_new_keys(
-    xresources, services_families, services_stack, res_root_stack, l_keys, nested=False,
+    xresources,
+    services_families,
+    services_stack,
+    res_root_stack,
+    l_keys,
+    nested=False,
 ):
     keys_r = []
     s_resources = res_root_stack.stack_template.resources
@@ -50,17 +54,16 @@ def handle_new_keys(
             )
 
     for key_name in xresources:
-        if key_name in keys_r:
-            perms = generate_resource_permissions(key_name, ACCESS_TYPES, KMS_KEY_ARN_T)
-            envvars = generate_resource_envvars(
-                key_name, xresources[key_name], KMS_KEY_ARN_T
+        key = xresources[key_name]
+        if key.logical_name in keys_r:
+            perms = generate_resource_permissions(
+                key.logical_name, ACCESS_TYPES, KMS_KEY_ARN_T
             )
             apply_iam_based_resources(
-                xresources[key_name],
+                key,
                 services_families,
                 services_stack,
                 res_root_stack,
-                envvars,
                 perms,
                 nested,
             )
